searchData={"items":[{"type":"module","doc":"This module provides the functionality to interact with the GoTrue API,\nallowing management of users, sessions, and authentication.\n\nIt also aims to provide integrations with Plug and Phoenix LiveView applications.\n\nFor detailed information about the GoTrue API, check the official documentation at https://supabase.io/docs/reference/javascript/auth-api\n\nAnd also refer to functions and submodules documentation for more information.","title":"Supabase.GoTrue","ref":"Supabase.GoTrue.html"},{"type":"function","doc":"Get the user associated with the current session.","title":"Supabase.GoTrue.get_user/2","ref":"Supabase.GoTrue.html#get_user/2"},{"type":"function","doc":"- `client` - The `Supabase` client to use for the request.\n  - `session` - The session to use for the request. Check `Supabase.GoTrue.Session` for more information.","title":"Parameters - Supabase.GoTrue.get_user/2","ref":"Supabase.GoTrue.html#get_user/2-parameters"},{"type":"function","doc":"iex> session = %Supabase.GoTrue.Session{access_token: \"example_token\"}\n    iex> Supabase.GoTrue.get_user(pid | client_name, session)\n    {:ok, %Supabase.GoTrue.User{}}","title":"Examples - Supabase.GoTrue.get_user/2","ref":"Supabase.GoTrue.html#get_user/2-examples"},{"type":"function","doc":"Resends a signuo confirm email for the given email address.","title":"Supabase.GoTrue.resend/3","ref":"Supabase.GoTrue.html#resend/3"},{"type":"function","doc":"- `client` - The `Supabase` client to use for the request.\n  - `email` - A valid user email address to recover password\n  - `opts`:\n    - `redirect_to`: the url where the user should be redirected to reset their password\n    - `captcha_token`","title":"Parameters - Supabase.GoTrue.resend/3","ref":"Supabase.GoTrue.html#resend/3-parameters"},{"type":"function","doc":"iex> Supabase.GoTrue.resend(client, \"john@example.com\", redirect_to: \"http://localohst:4000/reset-pass\")\n  :ok","title":"Examples - Supabase.GoTrue.resend/3","ref":"Supabase.GoTrue.html#resend/3-examples"},{"type":"function","doc":"Sends a recovery password email for the given email address.","title":"Supabase.GoTrue.reset_password_for_email/3","ref":"Supabase.GoTrue.html#reset_password_for_email/3"},{"type":"function","doc":"- `client` - The `Supabase` client to use for the request.\n  - `email` - A valid user email address to recover password\n  - `opts`:\n    - `redirect_to`: the url where the user should be redirected to reset their password\n    - `captcha_token`","title":"Parameters - Supabase.GoTrue.reset_password_for_email/3","ref":"Supabase.GoTrue.html#reset_password_for_email/3-parameters"},{"type":"function","doc":"iex> Supabase.GoTrue.reset_password_for_email(client, \"john@example.com\", redirect_to: \"http://localohst:4000/reset-pass\")\n  :ok","title":"Examples - Supabase.GoTrue.reset_password_for_email/3","ref":"Supabase.GoTrue.html#reset_password_for_email/3-examples"},{"type":"function","doc":"Signs in a user with ID token.","title":"Supabase.GoTrue.sign_in_with_id_token/2","ref":"Supabase.GoTrue.html#sign_in_with_id_token/2"},{"type":"function","doc":"- `client` - The `Supabase` client to use for the request.\n  - `credentials` - The credentials to use for the sign in. Check `Supabase.GoTrue.Schemas.SignInWithIdToken` for more information.","title":"Parameters - Supabase.GoTrue.sign_in_with_id_token/2","ref":"Supabase.GoTrue.html#sign_in_with_id_token/2-parameters"},{"type":"function","doc":"iex> credentials = %Supabase.GoTrue.SignInWithIdToken{}\n    iex> Supabase.GoTrue.sign_in_with_id_token(pid | client_name, credentials)\n    {:ok, %Supabase.GoTrue.User{}}","title":"Examples - Supabase.GoTrue.sign_in_with_id_token/2","ref":"Supabase.GoTrue.html#sign_in_with_id_token/2-examples"},{"type":"function","doc":"Signs in a user with OAuth.","title":"Supabase.GoTrue.sign_in_with_oauth/2","ref":"Supabase.GoTrue.html#sign_in_with_oauth/2"},{"type":"function","doc":"- `client` - The `Supabase` client to use for the request.\n  - `credentials` - The credentials to use for the sign in. Check `Supabase.GoTrue.Schemas.SignInWithOauth` for more information.","title":"Parameters - Supabase.GoTrue.sign_in_with_oauth/2","ref":"Supabase.GoTrue.html#sign_in_with_oauth/2-parameters"},{"type":"function","doc":"iex> credentials = %Supabase.GoTrue.SignInWithOauth{}\n    iex> Supabase.GoTrue.sign_in_with_oauth(pid | client_name, credentials)\n    {:ok, atom, URI.t()}","title":"Examples - Supabase.GoTrue.sign_in_with_oauth/2","ref":"Supabase.GoTrue.html#sign_in_with_oauth/2-examples"},{"type":"function","doc":"Signs in a user with OTP.","title":"Supabase.GoTrue.sign_in_with_otp/2","ref":"Supabase.GoTrue.html#sign_in_with_otp/2"},{"type":"function","doc":"- `client` - The `Supabase` client to use for the request.\n  - `credentials` - The credentials to use for the sign in. Check `Supabase.GoTrue.Schemas.SignInWithOTP` for more information.","title":"Parameters - Supabase.GoTrue.sign_in_with_otp/2","ref":"Supabase.GoTrue.html#sign_in_with_otp/2-parameters"},{"type":"function","doc":"iex> credentials = %Supabase.GoTrue.SignInWithOTP{}\n    iex> Supabase.GoTrue.sign_in_with_otp(pid | client_name, credentials)\n    {:ok, %Supabase.GoTrue.Session{}}","title":"Examples - Supabase.GoTrue.sign_in_with_otp/2","ref":"Supabase.GoTrue.html#sign_in_with_otp/2-examples"},{"type":"function","doc":"Signs in a user with email/phone and password.","title":"Supabase.GoTrue.sign_in_with_password/2","ref":"Supabase.GoTrue.html#sign_in_with_password/2"},{"type":"function","doc":"- `client` - The `Supabase` client to use for the request.\n  - `credentials` - The credentials to use for the sign in. Check `Supabase.GoTrue.Schemas.SignInWithPassword` for more information.","title":"Parameters - Supabase.GoTrue.sign_in_with_password/2","ref":"Supabase.GoTrue.html#sign_in_with_password/2-parameters"},{"type":"function","doc":"iex> credentials = %Supabase.GoTrue.SignInWithPassword{}\n    iex> Supabase.GoTrue.sign_in_with_password(pid | client_name, credentials)\n    {:ok, %Supabase.GoTrue.Session{}}","title":"Examples - Supabase.GoTrue.sign_in_with_password/2","ref":"Supabase.GoTrue.html#sign_in_with_password/2-examples"},{"type":"function","doc":"Signs in a user with SSO.","title":"Supabase.GoTrue.sign_in_with_sso/2","ref":"Supabase.GoTrue.html#sign_in_with_sso/2"},{"type":"function","doc":"- `client` - The `Supabase` client to use for the request.\n  - `credentials` - The credentials to use for the sign in. Check `Supabase.GoTrue.Schemas.SignInWithSSO` for more information.","title":"Parameters - Supabase.GoTrue.sign_in_with_sso/2","ref":"Supabase.GoTrue.html#sign_in_with_sso/2-parameters"},{"type":"function","doc":"iex> credentials = %Supabase.GoTrue.SignInWithSSO{}\n    iex> Supabase.GoTrue.sign_in_with_sso(pid | client_name, credentials)\n    {:ok, %Supabase.GoTrue.User{}}","title":"Examples - Supabase.GoTrue.sign_in_with_sso/2","ref":"Supabase.GoTrue.html#sign_in_with_sso/2-examples"},{"type":"function","doc":"Signs up a user with email/phone and password.","title":"Supabase.GoTrue.sign_up/2","ref":"Supabase.GoTrue.html#sign_up/2"},{"type":"function","doc":"- `client` - The `Supabase` client to use for the request.\n  - `credentials` - The credentials to use for the sign up. Check `Supabase.GoTrue.Schemas.SignUpWithPassword` for more information.","title":"Parameters - Supabase.GoTrue.sign_up/2","ref":"Supabase.GoTrue.html#sign_up/2-parameters"},{"type":"function","doc":"iex> credentials = %Supabase.GoTrue.SignUpWithPassword{}\n    iex> Supabase.GoTrue.sign_up(pid | client_name, credentials)\n    {:ok, %Supabase.GoTrue.User{}}","title":"Examples - Supabase.GoTrue.sign_up/2","ref":"Supabase.GoTrue.html#sign_up/2-examples"},{"type":"function","doc":"Updates the current logged in user.","title":"Supabase.GoTrue.update_user/3","ref":"Supabase.GoTrue.html#update_user/3"},{"type":"function","doc":"- `client` - The `Supabase` client to use for the request.\n  - `conn` - The current `Plug.Conn` or `Phoenix.LiveView.Socket` to get current user\n  - `attrs` - Check `UserParams`","title":"Parameters - Supabase.GoTrue.update_user/3","ref":"Supabase.GoTrue.html#update_user/3-parameters"},{"type":"function","doc":"iex> params = %{email: \"another@example.com\", password: \"new-pass\"}\n  iex> Supabase.GoTrue.update_user(client, conn, params)\n  {:ok, conn}","title":"Examples - Supabase.GoTrue.update_user/3","ref":"Supabase.GoTrue.html#update_user/3-examples"},{"type":"function","doc":"Verifies an OTP code.","title":"Supabase.GoTrue.verify_otp/2","ref":"Supabase.GoTrue.html#verify_otp/2"},{"type":"function","doc":"- `client` - The `Supabase` client to use for the request.\n  - `params` - The parameters to use for the verification. Check `Supabase.GoTrue.Schemas.VerifyOTP` for more information.","title":"Parameters - Supabase.GoTrue.verify_otp/2","ref":"Supabase.GoTrue.html#verify_otp/2-parameters"},{"type":"function","doc":"iex> params = %Supabase.GoTrue.VerifyOTP{}\n    iex> Supabase.GoTrue.verify_otp(pid | client_name, params)\n    {:ok, %Supabase.GoTrue.Session{}}","title":"Examples - Supabase.GoTrue.verify_otp/2","ref":"Supabase.GoTrue.html#verify_otp/2-examples"},{"type":"module","doc":"Admin module for GoTrue. This module provides functions to interact with the GoTrue admin API,\nlike signing out a user, inviting a user, and generating a link.\n\nYou can find more information about the GoTrue admin API at https://supabase.io/docs/reference/javascript/auth-admin-api","title":"Supabase.GoTrue.Admin","ref":"Supabase.GoTrue.Admin.html"},{"type":"function","doc":"Creates a user in the GoTrue admin API.","title":"Supabase.GoTrue.Admin.create_user/2","ref":"Supabase.GoTrue.Admin.html#create_user/2"},{"type":"function","doc":"* `client` - The `Supabase` client to use for the request.\n  * `attrs` - The attributes to use for the user. See `Supabase.GoTrue.Schemas.AdminUserParams` for more information.","title":"Parameters - Supabase.GoTrue.Admin.create_user/2","ref":"Supabase.GoTrue.Admin.html#create_user/2-parameters"},{"type":"function","doc":"iex> Supabase.GoTrue.Admin.create_user(pid | client_name, %{})","title":"Examples - Supabase.GoTrue.Admin.create_user/2","ref":"Supabase.GoTrue.Admin.html#create_user/2-examples"},{"type":"function","doc":"Deletes a user in the GoTrue admin API.","title":"Supabase.GoTrue.Admin.delete_user/3","ref":"Supabase.GoTrue.Admin.html#delete_user/3"},{"type":"function","doc":"* `client` - The `Supabase` client to use for the request.\n  * `user_id` - The ID of the user to delete.\n  * `opts` - Controls if the user should be soft deleted or not.","title":"Parameters - Supabase.GoTrue.Admin.delete_user/3","ref":"Supabase.GoTrue.Admin.html#delete_user/3-parameters"},{"type":"function","doc":"iex> Supabase.GoTrue.Admin.update_user(pid | client_name, \"user_id\", %{})","title":"Examples - Supabase.GoTrue.Admin.delete_user/3","ref":"Supabase.GoTrue.Admin.html#delete_user/3-examples"},{"type":"function","doc":"Generates a link for the GoTrue admin API.","title":"Supabase.GoTrue.Admin.generate_link/2","ref":"Supabase.GoTrue.Admin.html#generate_link/2"},{"type":"function","doc":"* `client` - The `Supabase` client to use for the request.\n  * `attrs` - The attributes to use for the link. See `Supabase.GoTrue.Schemas.GenerateLink` for more information.","title":"Parameters - Supabase.GoTrue.Admin.generate_link/2","ref":"Supabase.GoTrue.Admin.html#generate_link/2-parameters"},{"type":"function","doc":"iex> Supabase.GoTrue.Admin.generate_link(pid | client_name, %{})","title":"Examples - Supabase.GoTrue.Admin.generate_link/2","ref":"Supabase.GoTrue.Admin.html#generate_link/2-examples"},{"type":"function","doc":"Gets a user by ID in the GoTrue admin API.","title":"Supabase.GoTrue.Admin.get_user_by_id/2","ref":"Supabase.GoTrue.Admin.html#get_user_by_id/2"},{"type":"function","doc":"* `client` - The `Supabase` client to use for the request.\n  * `user_id` - The ID of the user to get.","title":"Parameters - Supabase.GoTrue.Admin.get_user_by_id/2","ref":"Supabase.GoTrue.Admin.html#get_user_by_id/2-parameters"},{"type":"function","doc":"iex> Supabase.GoTrue.Admin.get_user_by_id(pid | client_name, \"user_id\")","title":"Examples - Supabase.GoTrue.Admin.get_user_by_id/2","ref":"Supabase.GoTrue.Admin.html#get_user_by_id/2-examples"},{"type":"function","doc":"Invites a user to the GoTrue admin API.","title":"Supabase.GoTrue.Admin.invite_user_by_email/3","ref":"Supabase.GoTrue.Admin.html#invite_user_by_email/3"},{"type":"function","doc":"* `client` - The `Supabase` client to use for the request.\n  * `email` - The email of the user to invite.\n  * `options` - The options to use for the invite. See `Supabase.GoTrue.Schemas.InviteUserParams` for more information.","title":"Parameters - Supabase.GoTrue.Admin.invite_user_by_email/3","ref":"Supabase.GoTrue.Admin.html#invite_user_by_email/3-parameters"},{"type":"function","doc":"iex> Supabase.GoTrue.Admin.invite_user_by_email(pid | client_name, \"john@example.com\", %{})","title":"Examples - Supabase.GoTrue.Admin.invite_user_by_email/3","ref":"Supabase.GoTrue.Admin.html#invite_user_by_email/3-examples"},{"type":"function","doc":"Lists users in the GoTrue admin API.","title":"Supabase.GoTrue.Admin.list_users/2","ref":"Supabase.GoTrue.Admin.html#list_users/2"},{"type":"function","doc":"* `client` - The `Supabase` client to use for the request.\n  * `params` - The parameters to use for the list. See `Supabase.GoTrue.Schemas.PaginationParams` for more information.","title":"Parameters - Supabase.GoTrue.Admin.list_users/2","ref":"Supabase.GoTrue.Admin.html#list_users/2-parameters"},{"type":"function","doc":"iex> Supabase.GoTrue.Admin.list_users(pid | client_name, %{})","title":"Examples - Supabase.GoTrue.Admin.list_users/2","ref":"Supabase.GoTrue.Admin.html#list_users/2-examples"},{"type":"function","doc":"Signs out a user from the GoTrue admin API.","title":"Supabase.GoTrue.Admin.sign_out/3","ref":"Supabase.GoTrue.Admin.html#sign_out/3"},{"type":"function","doc":"* `client` - The `Supabase` client to use for the request.\n  * `session` - The session to sign out, often retrieved from a sign in function.\n  * `scope` - The scope to sign out the user from. Can be one of `global`, `local`, or `others`.","title":"Parameters - Supabase.GoTrue.Admin.sign_out/3","ref":"Supabase.GoTrue.Admin.html#sign_out/3-parameters"},{"type":"function","doc":"iex> session = %Session{access_token: \"access_token\"}\n    iex> Supabase.GoTrue.Admin.sign_out(pid | client_name, session, \"global\")","title":"Examples - Supabase.GoTrue.Admin.sign_out/3","ref":"Supabase.GoTrue.Admin.html#sign_out/3-examples"},{"type":"function","doc":"Updates a user in the GoTrue admin API.","title":"Supabase.GoTrue.Admin.update_user_by_id/3","ref":"Supabase.GoTrue.Admin.html#update_user_by_id/3"},{"type":"function","doc":"* `client` - The `Supabase` client to use for the request.\n  * `user_id` - The ID of the user to update.\n  * `attrs` - The attributes to use for the user. See `Supabase.GoTrue.Schemas.AdminUserParams` for more information.","title":"Parameters - Supabase.GoTrue.Admin.update_user_by_id/3","ref":"Supabase.GoTrue.Admin.html#update_user_by_id/3-parameters"},{"type":"function","doc":"iex> Supabase.GoTrue.Admin.update_user(pid | client_name, \"user_id\", %{})","title":"Examples - Supabase.GoTrue.Admin.update_user_by_id/3","ref":"Supabase.GoTrue.Admin.html#update_user_by_id/3-examples"},{"type":"module","doc":"This module contains the authentication logic for Supabase GoTrue.","title":"Supabase.GoTrue.Auth","ref":"Supabase.GoTrue.Auth.html"},{"type":"function","doc":"","title":"Supabase.GoTrue.Auth.parse/2","ref":"Supabase.GoTrue.Auth.html#parse/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.Auth.parse_mfa/1","ref":"Supabase.GoTrue.Auth.html#parse_mfa/1"},{"type":"module","doc":"","title":"Supabase.GoTrue.Auth.MFA","ref":"Supabase.GoTrue.Auth.MFA.html"},{"type":"module","doc":"","title":"Supabase.GoTrue.Auth.MFA.Challenge","ref":"Supabase.GoTrue.Auth.MFA.Challenge.html"},{"type":"module","doc":"","title":"Supabase.GoTrue.Auth.MFA.ChallengeAndVerify","ref":"Supabase.GoTrue.Auth.MFA.ChallengeAndVerify.html"},{"type":"module","doc":"","title":"Supabase.GoTrue.Auth.MFA.Enroll","ref":"Supabase.GoTrue.Auth.MFA.Enroll.html"},{"type":"module","doc":"","title":"Supabase.GoTrue.Auth.MFA.UnEnroll","ref":"Supabase.GoTrue.Auth.MFA.UnEnroll.html"},{"type":"module","doc":"","title":"Supabase.GoTrue.Auth.MFA.Verify","ref":"Supabase.GoTrue.Auth.MFA.Verify.html"},{"type":"module","doc":"","title":"Supabase.GoTrue.Auth.NetWorkFailure","ref":"Supabase.GoTrue.Auth.NetWorkFailure.html"},{"type":"module","doc":"Provides LiveView integrations for the Supabase GoTrue authentication in Elixir applications.\n\nThis module enables the seamless integration of authentication flows within Phoenix LiveView applications by leveraging the Supabase GoTrue SDK. It supports operations such as mounting current users, handling authenticated and unauthenticated states, and logging out users.","title":"Supabase.GoTrue.LiveView","ref":"Supabase.GoTrue.LiveView.html"},{"type":"module","doc":"The module requires some application environment variables to be set:\n- `authentication_client`: The Supabase client used for authentication.\n- `endpoint`: Your web app endpoint, used internally for broadcasting user disconnection events.\n- `signed_in_path`: The route to where socket should be redirected to after authentication\n\nYou can set up these config in your `config.exs`:\n```\nconfig :supabase_gotrue,\n  endpoint: YourApp.Endpoint,\n  signed_in_path: \"/dashboard\",\n  authentication_client: :my_supabase_potion_client_name\n```","title":"Configuration - Supabase.GoTrue.LiveView","ref":"Supabase.GoTrue.LiveView.html#module-configuration"},{"type":"module","doc":"Typically, this module is used in your `YourAppWeb.Router`, to handle user authentication states through a series of `on_mount` callbacks, which ensure that user authentication logic is processed during the LiveView lifecycle.\n\nCheck `on_mount/4` for more detailed usage instructions on LiveViews","title":"Usage - Supabase.GoTrue.LiveView","ref":"Supabase.GoTrue.LiveView.html#module-usage"},{"type":"function","doc":"Logs out the user from the session and broadcasts a disconnect event.","title":"Supabase.GoTrue.LiveView.log_out_user/2","ref":"Supabase.GoTrue.LiveView.html#log_out_user/2"},{"type":"function","doc":"- `socket`: The `Phoenix.LiveView.Socket` representing the current LiveView state.\n- `scope`: An optional scope parameter for the logout request. Check `Supabase.GoTrue.Admin.sign_out/3` for more detailed information.","title":"Parameters - Supabase.GoTrue.LiveView.log_out_user/2","ref":"Supabase.GoTrue.LiveView.html#log_out_user/2-parameters"},{"type":"function","doc":"iex> log_out_user(socket, :local)\n    # Broadcasts 'disconnect' and removes the user session","title":"Examples - Supabase.GoTrue.LiveView.log_out_user/2","ref":"Supabase.GoTrue.LiveView.html#log_out_user/2-examples"},{"type":"function","doc":"","title":"Supabase.GoTrue.LiveView.mount_current_user/2","ref":"Supabase.GoTrue.LiveView.html#mount_current_user/2"},{"type":"function","doc":"Handles mounting and authenticating the current_user in LiveViews.\n\n## `on_mount` arguments\n  * `:mount_current_user` - Assigns current_user\n    to socket assigns based on user_token, or nil if\n    there's no user_token or no matching user.\n  * `:ensure_authenticated` - Authenticates the user from the session,\n    and assigns the current_user to socket assigns based\n    on user_token.\n    Redirects to login page if there's no logged user.\n  * `:redirect_if_user_is_authenticated` - Authenticates the user from the session.\n    Redirects to signed_in_path if there's a logged user.","title":"Supabase.GoTrue.LiveView.on_mount/4","ref":"Supabase.GoTrue.LiveView.html#on_mount/4"},{"type":"function","doc":"Use the `on_mount` lifecycle macro in LiveViews to mount or authenticate\nthe current_user:\n    defmodule PescarteWeb.PageLive do\n      use PescarteWeb, :live_view\n      on_mount {PescarteWeb.Authentication, :mount_current_user}\n      ...\n    end\nOr use the `live_session` of your router to invoke the on_mount callback:\n    live_session :authenticated, on_mount: [{PescarteWeb.UserAuth, :ensure_authenticated}] do\n      live \"/profile\", ProfileLive, :index\n    end","title":"Examples - Supabase.GoTrue.LiveView.on_mount/4","ref":"Supabase.GoTrue.LiveView.html#on_mount/4-examples"},{"type":"module","doc":"This module is used to generate PKCE (Proof Key for Code Exchange) values.","title":"Supabase.GoTrue.PKCE","ref":"Supabase.GoTrue.PKCE.html"},{"type":"function","doc":"","title":"Supabase.GoTrue.PKCE.generate_challenge/1","ref":"Supabase.GoTrue.PKCE.html#generate_challenge/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.PKCE.generate_verifier/0","ref":"Supabase.GoTrue.PKCE.html#generate_verifier/0"},{"type":"module","doc":"Provides Plug-based authentication support for the Supabase GoTrue authentication in Elixir applications.\n\nThis module offers a series of functions to manage user authentication through HTTP requests in Phoenix applications. It facilitates operations like logging in with a password, logging out users, fetching the current user from a session, and handling route protections based on authentication state.","title":"Supabase.GoTrue.Plug","ref":"Supabase.GoTrue.Plug.html"},{"type":"module","doc":"The module requires some application environment variables to be set:\n- `authentication_client`: The Supabase client used for authentication.\n- `signed_in_path`: The route to where conn should be redirected to after authentication\n- `not_authenticated_path `: The route to where conn should be redirect to if user isn't authenticated\n\nYou can set up these config in your `config.exs`:\n```\nconfig :supabase_gotrue,\n  signed_in_path: \"/dashboard\",\n  not_authenticated_path: \"/login\",\n  authentication_client: :my_supabase_potion_client_name\n```","title":"Configuration - Supabase.GoTrue.Plug","ref":"Supabase.GoTrue.Plug.html#module-configuration"},{"type":"module","doc":"It handles session management, cookie operations, and redirects based on user authentication status, providing a seamless integration for user sessions within Phoenix routes.","title":"Authentication Flow - Supabase.GoTrue.Plug","ref":"Supabase.GoTrue.Plug.html#module-authentication-flow"},{"type":"function","doc":"Retrieves the current user from the session or a signed cookie, assigning it to the connection's assigns.\n\nCan be easily used as a plug, for example inside a Phoenix web app\npipeline in your `YourAppWeb.Router`, you can do something like:\n```\nimport Supabase.GoTrue.Plug\n\npipeline :browser do\n  plug :fetch_session # comes from Plug.Conn\n  plug :fetch_current_user\n  # rest of plug chain...\nend\n```","title":"Supabase.GoTrue.Plug.fetch_current_user/2","ref":"Supabase.GoTrue.Plug.html#fetch_current_user/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.Plug.log_in_with_id_token/2","ref":"Supabase.GoTrue.Plug.html#log_in_with_id_token/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.Plug.log_in_with_oauth/2","ref":"Supabase.GoTrue.Plug.html#log_in_with_oauth/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.Plug.log_in_with_otp/2","ref":"Supabase.GoTrue.Plug.html#log_in_with_otp/2"},{"type":"function","doc":"Logs in a user using a username and password. Stores the user token in the session and a cookie, if a `\"remember_me\"` key is present inside `params`.\n\nFor more information on how Supabase login with email and password works, check `Supabase.GoTrue.sign_in_with_password/2`","title":"Supabase.GoTrue.Plug.log_in_with_password/2","ref":"Supabase.GoTrue.Plug.html#log_in_with_password/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.Plug.log_in_with_sso/2","ref":"Supabase.GoTrue.Plug.html#log_in_with_sso/2"},{"type":"function","doc":"Logs out the user from the application, clearing session data","title":"Supabase.GoTrue.Plug.log_out_user/2","ref":"Supabase.GoTrue.Plug.html#log_out_user/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.Plug.put_token_in_session/2","ref":"Supabase.GoTrue.Plug.html#put_token_in_session/2"},{"type":"function","doc":"Redirects an user to the configured `signed_in_path` if it is authenticated, if not, just halts the connection.\n\nGeneraly you wan to use it inside your scopes routes inside `YourAppWeb.Router`:\n```\nscope \"/\" do\n  pipe_trough [:browser, :redirect_if_user_is_authenticated]\n\n  get \"/login\", LoginController, :login\nend\n```","title":"Supabase.GoTrue.Plug.redirect_if_user_is_authenticated/2","ref":"Supabase.GoTrue.Plug.html#redirect_if_user_is_authenticated/2"},{"type":"function","doc":"Ensures an user is authenticated before executing the rest of Plugs chain.\n\nGeneraly you wan to use it inside your scopes routes inside `YourAppWeb.Router`:\n```\nscope \"/\" do\n  pipe_trough [:browser, :require_authenticated_user]\n\n  get \"/super-secret\", SuperSecretController, :secret\nend\n```","title":"Supabase.GoTrue.Plug.require_authenticated_user/2","ref":"Supabase.GoTrue.Plug.html#require_authenticated_user/2"},{"type":"module","doc":"Admin user params schema. This schema is used to validate and parse the parameters for creating a new admin user.","title":"Supabase.GoTrue.Schemas.AdminUserParams","ref":"Supabase.GoTrue.Schemas.AdminUserParams.html"},{"type":"module","doc":"* `app_metadata` - The metadata to associate with the user.\n  * `email_confirm` - Whether the user's email is confirmed.\n  * `phone_confirm` - Whether the user's phone is confirmed.\n  * `ban_duration` - The duration of the user's ban.\n  * `role` - The user's role.\n  * `email` - The user's email.\n  * `phone` - The user's phone.\n  * `password` - The user's password.\n  * `nonce` - The user's nonce.","title":"Fields - Supabase.GoTrue.Schemas.AdminUserParams","ref":"Supabase.GoTrue.Schemas.AdminUserParams.html#module-fields"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.AdminUserParams.parse/1","ref":"Supabase.GoTrue.Schemas.AdminUserParams.html#parse/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.AdminUserParams.parse_update/1","ref":"Supabase.GoTrue.Schemas.AdminUserParams.html#parse_update/1"},{"type":"module","doc":"This module is responsible for generating links for different actions.","title":"Supabase.GoTrue.Schemas.GenerateLink","ref":"Supabase.GoTrue.Schemas.GenerateLink.html"},{"type":"module","doc":"* `action_link` - The link to the action.\n  * `email_otp` - The email one-time password.\n  * `hashed_token` - The hashed token.\n  * `redirect_to` - The redirect URL.\n  * `verification_type` - The type of verification.\n    - `signup`\n    - `invite`\n    - `magicLink`\n    - `recovery`\n    - `email_change_current`\n    - `email_change_new`\n  * `options` - The options for the link.\n    - `data` - The data for the link.\n    - `redirect_to` - The redirect URL.","title":"Fields - Supabase.GoTrue.Schemas.GenerateLink","ref":"Supabase.GoTrue.Schemas.GenerateLink.html#module-fields"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.GenerateLink.email_change_params/1","ref":"Supabase.GoTrue.Schemas.GenerateLink.html#email_change_params/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.GenerateLink.invite_or_magic_link_params/1","ref":"Supabase.GoTrue.Schemas.GenerateLink.html#invite_or_magic_link_params/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.GenerateLink.parse/1","ref":"Supabase.GoTrue.Schemas.GenerateLink.html#parse/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.GenerateLink.properties/1","ref":"Supabase.GoTrue.Schemas.GenerateLink.html#properties/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.GenerateLink.recovery_params/1","ref":"Supabase.GoTrue.Schemas.GenerateLink.html#recovery_params/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.GenerateLink.sign_up_params/1","ref":"Supabase.GoTrue.Schemas.GenerateLink.html#sign_up_params/1"},{"type":"behaviour","doc":"This schema is used to validate and parse the parameters for inviting a new user.","title":"Supabase.GoTrue.Schemas.InviteUserParams","ref":"Supabase.GoTrue.Schemas.InviteUserParams.html"},{"type":"behaviour","doc":"* `data` - The data for the link.\n  * `redirect_to` - The redirect URL.","title":"Fields - Supabase.GoTrue.Schemas.InviteUserParams","ref":"Supabase.GoTrue.Schemas.InviteUserParams.html#module-fields"},{"type":"callback","doc":"","title":"Supabase.GoTrue.Schemas.InviteUserParams.changeset/2","ref":"Supabase.GoTrue.Schemas.InviteUserParams.html#c:changeset/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.InviteUserParams.parse/1","ref":"Supabase.GoTrue.Schemas.InviteUserParams.html#parse/1"},{"type":"callback","doc":"","title":"Supabase.GoTrue.Schemas.InviteUserParams.parse/1","ref":"Supabase.GoTrue.Schemas.InviteUserParams.html#c:parse/1"},{"type":"opaque","doc":"","title":"Supabase.GoTrue.Schemas.InviteUserParams.changeset/0","ref":"Supabase.GoTrue.Schemas.InviteUserParams.html#t:changeset/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.Schemas.InviteUserParams.t/0","ref":"Supabase.GoTrue.Schemas.InviteUserParams.html#t:t/0"},{"type":"module","doc":"This schema is used to validate and parse the parameters for pagination.","title":"Supabase.GoTrue.Schemas.PaginationParams","ref":"Supabase.GoTrue.Schemas.PaginationParams.html"},{"type":"module","doc":"* `page` - The current page.\n  * `per_page` - The number of items per page.","title":"Fields - Supabase.GoTrue.Schemas.PaginationParams","ref":"Supabase.GoTrue.Schemas.PaginationParams.html#module-fields"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.PaginationParams.page_params/1","ref":"Supabase.GoTrue.Schemas.PaginationParams.html#page_params/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.PaginationParams.pagination/1","ref":"Supabase.GoTrue.Schemas.PaginationParams.html#pagination/1"},{"type":"module","doc":"This schema is used to validate and parse the parameters for signing in a user.","title":"Supabase.GoTrue.Schemas.SignInRequest","ref":"Supabase.GoTrue.Schemas.SignInRequest.html"},{"type":"module","doc":"Fields depends on the sign in method, so check their modules to\nsee the available fields.\n- Sign in with ID Token: `Supabase.GoTrue.Schemas.SignInWithIdToken`\n- Sign in with OTP: `Supabase.GoTrue.Schemas.SignInWithOTP`\n- Sign in with Password: `Supabase.GoTrue.Schemas.SignInWithPassword`\n- Sign in with SSO: `Supabase.GoTrue.Schemas.SignInWithSSO`","title":"Fields - Supabase.GoTrue.Schemas.SignInRequest","ref":"Supabase.GoTrue.Schemas.SignInRequest.html#module-fields"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInRequest.create/1","ref":"Supabase.GoTrue.Schemas.SignInRequest.html#create/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInRequest.create/3","ref":"Supabase.GoTrue.Schemas.SignInRequest.html#create/3"},{"type":"module","doc":"","title":"Supabase.GoTrue.Schemas.SignInRequest.GoTrueMetaSecurity","ref":"Supabase.GoTrue.Schemas.SignInRequest.GoTrueMetaSecurity.html"},{"type":"behaviour","doc":"This schema is used to validate and parse the parameters for signing in with an ID token.","title":"Supabase.GoTrue.Schemas.SignInWithIdToken","ref":"Supabase.GoTrue.Schemas.SignInWithIdToken.html"},{"type":"behaviour","doc":"* `provider` - The provider.\n  * `token` - The token.\n  * `access_token` - The access token.\n  * `nonce` - The nonce.\n  * `options` - The options.\n    - `captcha_token` - The captcha token.","title":"Fields - Supabase.GoTrue.Schemas.SignInWithIdToken","ref":"Supabase.GoTrue.Schemas.SignInWithIdToken.html#module-fields"},{"type":"callback","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithIdToken.changeset/2","ref":"Supabase.GoTrue.Schemas.SignInWithIdToken.html#c:changeset/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithIdToken.parse/1","ref":"Supabase.GoTrue.Schemas.SignInWithIdToken.html#parse/1"},{"type":"callback","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithIdToken.parse/1","ref":"Supabase.GoTrue.Schemas.SignInWithIdToken.html#c:parse/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithIdToken.to_sign_in_params/1","ref":"Supabase.GoTrue.Schemas.SignInWithIdToken.html#to_sign_in_params/1"},{"type":"opaque","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithIdToken.changeset/0","ref":"Supabase.GoTrue.Schemas.SignInWithIdToken.html#t:changeset/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithIdToken.t/0","ref":"Supabase.GoTrue.Schemas.SignInWithIdToken.html#t:t/0"},{"type":"module","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithIdToken.Options","ref":"Supabase.GoTrue.Schemas.SignInWithIdToken.Options.html"},{"type":"behaviour","doc":"This schema is used to validate and parse the parameters for signing in with OTP.","title":"Supabase.GoTrue.Schemas.SignInWithOTP","ref":"Supabase.GoTrue.Schemas.SignInWithOTP.html"},{"type":"behaviour","doc":"* `email` - The user's email.\n  * `phone` - The user's phone.\n  * `options` - The options for signing in with OTP.\n    - `data` - The data for the sign in.\n    - `email_redirect_to` - The redirect URL for the email.\n    - `captcha_token` - The captcha token.\n    - `channel` - The channel for the OTP.","title":"Fields - Supabase.GoTrue.Schemas.SignInWithOTP","ref":"Supabase.GoTrue.Schemas.SignInWithOTP.html#module-fields"},{"type":"callback","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOTP.changeset/2","ref":"Supabase.GoTrue.Schemas.SignInWithOTP.html#c:changeset/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOTP.parse/1","ref":"Supabase.GoTrue.Schemas.SignInWithOTP.html#parse/1"},{"type":"callback","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOTP.parse/1","ref":"Supabase.GoTrue.Schemas.SignInWithOTP.html#c:parse/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOTP.to_sign_in_params/1","ref":"Supabase.GoTrue.Schemas.SignInWithOTP.html#to_sign_in_params/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOTP.to_sign_in_params/3","ref":"Supabase.GoTrue.Schemas.SignInWithOTP.html#to_sign_in_params/3"},{"type":"opaque","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOTP.changeset/0","ref":"Supabase.GoTrue.Schemas.SignInWithOTP.html#t:changeset/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOTP.options/0","ref":"Supabase.GoTrue.Schemas.SignInWithOTP.html#t:options/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOTP.t/0","ref":"Supabase.GoTrue.Schemas.SignInWithOTP.html#t:t/0"},{"type":"module","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOTP.Options","ref":"Supabase.GoTrue.Schemas.SignInWithOTP.Options.html"},{"type":"behaviour","doc":"This schema is used to validate and parse the parameters for signing in with OAuth.","title":"Supabase.GoTrue.Schemas.SignInWithOauth","ref":"Supabase.GoTrue.Schemas.SignInWithOauth.html"},{"type":"behaviour","doc":"* `provider` - The provider.\n  * `options` - The options.\n    - `redirect_to` - The redirect URL.\n    - `scopes` - The scopes.\n    - `query_params` - The query parameters.\n    - `skip_browser_redirect` - Whether to skip the browser redirect.","title":"Fields - Supabase.GoTrue.Schemas.SignInWithOauth","ref":"Supabase.GoTrue.Schemas.SignInWithOauth.html#module-fields"},{"type":"callback","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOauth.changeset/2","ref":"Supabase.GoTrue.Schemas.SignInWithOauth.html#c:changeset/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOauth.options_to_query/1","ref":"Supabase.GoTrue.Schemas.SignInWithOauth.html#options_to_query/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOauth.parse/1","ref":"Supabase.GoTrue.Schemas.SignInWithOauth.html#parse/1"},{"type":"callback","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOauth.parse/1","ref":"Supabase.GoTrue.Schemas.SignInWithOauth.html#c:parse/1"},{"type":"opaque","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOauth.changeset/0","ref":"Supabase.GoTrue.Schemas.SignInWithOauth.html#t:changeset/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOauth.t/0","ref":"Supabase.GoTrue.Schemas.SignInWithOauth.html#t:t/0"},{"type":"module","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithOauth.Options","ref":"Supabase.GoTrue.Schemas.SignInWithOauth.Options.html"},{"type":"module","doc":"This schema is used to validate and parse the parameters for signing in with a password.","title":"Supabase.GoTrue.Schemas.SignInWithPassword","ref":"Supabase.GoTrue.Schemas.SignInWithPassword.html"},{"type":"module","doc":"* `email` - The user's email.\n  * `phone` - The user's phone.\n  * `password` - The user's password.\n  * `options` - The options for the sign in.\n    - `data` - The data for the sign in.\n    - `captcha_token` - The captcha token.","title":"Fields - Supabase.GoTrue.Schemas.SignInWithPassword","ref":"Supabase.GoTrue.Schemas.SignInWithPassword.html#module-fields"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithPassword.parse/1","ref":"Supabase.GoTrue.Schemas.SignInWithPassword.html#parse/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithPassword.to_sign_in_params/1","ref":"Supabase.GoTrue.Schemas.SignInWithPassword.html#to_sign_in_params/1"},{"type":"module","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithPassword.Options","ref":"Supabase.GoTrue.Schemas.SignInWithPassword.Options.html"},{"type":"behaviour","doc":"This schema is used to validate and parse the parameters for signing in with SSO.","title":"Supabase.GoTrue.Schemas.SignInWithSSO","ref":"Supabase.GoTrue.Schemas.SignInWithSSO.html"},{"type":"behaviour","doc":"* `provider_id` - The provider ID.\n  * `domain` - The domain.\n  * `options` - The options.\n    - `redirect_to` - The redirect URL.\n    - `captcha_token` - The captcha token.","title":"Fields - Supabase.GoTrue.Schemas.SignInWithSSO","ref":"Supabase.GoTrue.Schemas.SignInWithSSO.html#module-fields"},{"type":"callback","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithSSO.changeset/2","ref":"Supabase.GoTrue.Schemas.SignInWithSSO.html#c:changeset/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithSSO.parse/1","ref":"Supabase.GoTrue.Schemas.SignInWithSSO.html#parse/1"},{"type":"callback","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithSSO.parse/1","ref":"Supabase.GoTrue.Schemas.SignInWithSSO.html#c:parse/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithSSO.to_sign_in_params/1","ref":"Supabase.GoTrue.Schemas.SignInWithSSO.html#to_sign_in_params/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithSSO.to_sign_in_params/3","ref":"Supabase.GoTrue.Schemas.SignInWithSSO.html#to_sign_in_params/3"},{"type":"opaque","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithSSO.changeset/0","ref":"Supabase.GoTrue.Schemas.SignInWithSSO.html#t:changeset/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithSSO.options/0","ref":"Supabase.GoTrue.Schemas.SignInWithSSO.html#t:options/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithSSO.t/0","ref":"Supabase.GoTrue.Schemas.SignInWithSSO.html#t:t/0"},{"type":"module","doc":"","title":"Supabase.GoTrue.Schemas.SignInWithSSO.Options","ref":"Supabase.GoTrue.Schemas.SignInWithSSO.Options.html"},{"type":"module","doc":"This schema is used to validate and parse the parameters for signing up a new user.","title":"Supabase.GoTrue.Schemas.SignUpRequest","ref":"Supabase.GoTrue.Schemas.SignUpRequest.html"},{"type":"module","doc":"* `email` - The user's email.\n  * `phone` - The user's phone.\n  * `password` - The user's password.\n  * `data` - The user's data.\n  * `code_challenge` - The user's code challenge.\n  * `code_challenge_method` - The user's code challenge method.\n  * `gotrue_meta_security` - The user's gotrue meta security.\n    - `captcha_token` - The user's captcha token.","title":"Fields - Supabase.GoTrue.Schemas.SignUpRequest","ref":"Supabase.GoTrue.Schemas.SignUpRequest.html#module-fields"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignUpRequest.changeset/3","ref":"Supabase.GoTrue.Schemas.SignUpRequest.html#changeset/3"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignUpRequest.create/1","ref":"Supabase.GoTrue.Schemas.SignUpRequest.html#create/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.SignUpRequest.create/3","ref":"Supabase.GoTrue.Schemas.SignUpRequest.html#create/3"},{"type":"module","doc":"","title":"Supabase.GoTrue.Schemas.SignUpRequest.GoTrueMetaSecurity","ref":"Supabase.GoTrue.Schemas.SignUpRequest.GoTrueMetaSecurity.html"},{"type":"module","doc":"","title":"Supabase.GoTrue.Schemas.SignUpWithPassword.Options","ref":"Supabase.GoTrue.Schemas.SignUpWithPassword.Options.html"},{"type":"module","doc":"Uuser params schema. This schema is used to validate and parse the parameters for creating a new admin user.","title":"Supabase.GoTrue.Schemas.UserParams","ref":"Supabase.GoTrue.Schemas.UserParams.html"},{"type":"module","doc":"* `data` - The metadata to associate with the user.\n  * `email` - The user's email.\n  * `phone` - The user's phone.\n  * `password` - The user's password.\n  * `nonce` - The user's nonce.\n  * `email_redirect_to` - The user's nonce.","title":"Fields - Supabase.GoTrue.Schemas.UserParams","ref":"Supabase.GoTrue.Schemas.UserParams.html#module-fields"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.UserParams.parse/1","ref":"Supabase.GoTrue.Schemas.UserParams.html#parse/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.UserParams.parse_update/1","ref":"Supabase.GoTrue.Schemas.UserParams.html#parse_update/1"},{"type":"behaviour","doc":"This schema is used to validate and parse the parameters for verifying an OTP.","title":"Supabase.GoTrue.Schemas.VerifyOTP","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html"},{"type":"behaviour","doc":"","title":"Fields - Supabase.GoTrue.Schemas.VerifyOTP","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#module-fields"},{"type":"behaviour","doc":"* `phone` - The user's phone number.\n  * `token` - The OTP token.\n  * `type` - The type of OTP.\n  * `options` - The options for the OTP.\n    - `redirect_to` - The redirect URL.\n    - `captcha_token` - The captcha token.","title":"Mobile OTP - Supabase.GoTrue.Schemas.VerifyOTP","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#module-mobile-otp"},{"type":"behaviour","doc":"* `email` - The user's email.\n  * `token` - The OTP token.\n  * `type` - The type of OTP.\n  * `options` - The options for the OTP.\n    - `redirect_to` - The redirect URL.\n    - `captcha_token` - The captcha token.","title":"Email OTP - Supabase.GoTrue.Schemas.VerifyOTP","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#module-email-otp"},{"type":"behaviour","doc":"* `token_hash` - The token hash.\n  * `type` - The type of OTP.\n  * `options` - The options for the OTP.\n    - `redirect_to` - The redirect URL.\n    - `captcha_token` - The captcha token.","title":"Token Hash - Supabase.GoTrue.Schemas.VerifyOTP","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#module-token-hash"},{"type":"callback","doc":"","title":"Supabase.GoTrue.Schemas.VerifyOTP.changeset/2","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#c:changeset/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.VerifyOTP.parse/1","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#parse/1"},{"type":"callback","doc":"","title":"Supabase.GoTrue.Schemas.VerifyOTP.parse/1","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#c:parse/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.Schemas.VerifyOTP.to_request/1","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#to_request/1"},{"type":"opaque","doc":"","title":"Supabase.GoTrue.Schemas.VerifyOTP.changeset/0","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#t:changeset/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.Schemas.VerifyOTP.email/0","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#t:email/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.Schemas.VerifyOTP.mobile/0","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#t:mobile/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.Schemas.VerifyOTP.options/0","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#t:options/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.Schemas.VerifyOTP.t/0","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#t:t/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.Schemas.VerifyOTP.token_hash/0","ref":"Supabase.GoTrue.Schemas.VerifyOTP.html#t:token_hash/0"},{"type":"module","doc":"This schema is used to validate and parse the parameters for a session.","title":"Supabase.GoTrue.Session","ref":"Supabase.GoTrue.Session.html"},{"type":"module","doc":"* `provider_token` - The provider token.\n  * `provider_refresh_token` - The provider refresh token.\n  * `access_token` - The access token.\n  * `refresh_token` - The refresh token.\n  * `expires_in` - The expiration time.\n  * `expires_at` - The expiration date.\n  * `token_type` - The token type.\n  * `user` - The user. Check the `Supabase.GoTrue.User` schema for more information.","title":"Fields - Supabase.GoTrue.Session","ref":"Supabase.GoTrue.Session.html#module-fields"},{"type":"function","doc":"","title":"Supabase.GoTrue.Session.parse/1","ref":"Supabase.GoTrue.Session.html#parse/1"},{"type":"type","doc":"","title":"Supabase.GoTrue.Session.t/0","ref":"Supabase.GoTrue.Session.html#t:t/0"},{"type":"module","doc":"This schema is used to validate and parse the parameters for a user.","title":"Supabase.GoTrue.User","ref":"Supabase.GoTrue.User.html"},{"type":"module","doc":"* `id` - The user's ID.\n  * `app_metadata` - The metadata to associate with the user.\n  * `user_metadata` - The user's metadata.\n  * `aud` - The user's audience.\n  * `confirmation_sent_at` - The time the confirmation was sent.\n  * `recovery_sent_at` - The time the recovery was sent.\n  * `email_change_sent_at` - The time the email change was sent.\n  * `new_email` - The new email.\n  * `new_phone` - The new phone.\n  * `invited_at` - The time the user was invited.\n  * `action_link` - The action link.\n  * `email` - The user's email.\n  * `phone` - The user's phone.\n  * `created_at` - The time the user was created.\n  * `confirmed_at` - The time the user was confirmed.\n  * `email_confirmed_at` - The time the email was confirmed.\n  * `phone_confirmed_at` - The time the phone was confirmed.\n  * `last_sign_in_at` - The time the user last signed in.\n  * `last_sign_in_ip` - The user's last sign-in IP.\n  * `current_sign_in_at` - The time the user last signed in.\n  * `current_sign_in_ip` - The user's current sign-in IP.\n  * `sign_in_count` - The number of times the user has signed in.\n  * `factors` - The user's factors. Check the `Supabase.GoTrue.User.Factor` schema for more information.\n  * `identities` - The user's identities. Check the `Supabase.GoTrue.User.Identity` schema for more information.","title":"Fields - Supabase.GoTrue.User","ref":"Supabase.GoTrue.User.html#module-fields"},{"type":"function","doc":"","title":"Supabase.GoTrue.User.changeset/2","ref":"Supabase.GoTrue.User.html#changeset/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.User.multiple_changeset/2","ref":"Supabase.GoTrue.User.html#multiple_changeset/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.User.parse/1","ref":"Supabase.GoTrue.User.html#parse/1"},{"type":"function","doc":"","title":"Supabase.GoTrue.User.parse_list/1","ref":"Supabase.GoTrue.User.html#parse_list/1"},{"type":"type","doc":"","title":"Supabase.GoTrue.User.t/0","ref":"Supabase.GoTrue.User.html#t:t/0"},{"type":"module","doc":"This schema is used to validate and parse the parameters for a user factor.","title":"Supabase.GoTrue.User.Factor","ref":"Supabase.GoTrue.User.Factor.html"},{"type":"module","doc":"* `friendly_name` - The friendly name of the factor.\n  * `factor_type` - The type of factor.\n  * `status` - The status of the factor.\n  * `created_at` - The creation date of the factor.\n  * `updated_at` - The last update date of the factor.\n  * `id` - The factor's ID.","title":"Fields - Supabase.GoTrue.User.Factor","ref":"Supabase.GoTrue.User.Factor.html#module-fields"},{"type":"function","doc":"","title":"Supabase.GoTrue.User.Factor.changeset/2","ref":"Supabase.GoTrue.User.Factor.html#changeset/2"},{"type":"type","doc":"","title":"Supabase.GoTrue.User.Factor.t/0","ref":"Supabase.GoTrue.User.Factor.html#t:t/0"},{"type":"module","doc":"This schema is used to validate and parse the identity of a user.","title":"Supabase.GoTrue.User.Identity","ref":"Supabase.GoTrue.User.Identity.html"},{"type":"module","doc":"* `id` - The user's ID.\n  * `user_id` - The user's ID.\n  * `provider` - The user's provider.\n  * `created_at` - The user's creation date.\n  * `updated_at` - The user's last update date.\n  * `identity_data` - The user's identity data.\n  * `last_sign_in_at` - The user's last sign-in date.","title":"Fields - Supabase.GoTrue.User.Identity","ref":"Supabase.GoTrue.User.Identity.html#module-fields"},{"type":"function","doc":"","title":"Supabase.GoTrue.User.Identity.changeset/2","ref":"Supabase.GoTrue.User.Identity.html#changeset/2"},{"type":"function","doc":"","title":"Supabase.GoTrue.User.Identity.providers/0","ref":"Supabase.GoTrue.User.Identity.html#providers/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.User.Identity.providers/0","ref":"Supabase.GoTrue.User.Identity.html#t:providers/0"},{"type":"type","doc":"","title":"Supabase.GoTrue.User.Identity.t/0","ref":"Supabase.GoTrue.User.Identity.html#t:t/0"},{"type":"extras","doc":"# Supabase GoTrue\n\n[Auth](https://supabase.com/docs/guides/auth) implementation for the `supabase_potion` SDK in Elixir.","title":"Supabase GoTrue","ref":"readme.html"},{"type":"extras","doc":"```elixir\ndef deps do\n  [\n    {:supabase_potion, \"~> 0.3\"},\n    {:supabase_gotrue, \"~> 0.2\"}\n  ]\nend\n```","title":"Installation - Supabase GoTrue","ref":"readme.html#installation"},{"type":"extras","doc":"Firstly you need to initialize your Supabase client(s) as can be found on the [supabase_potion documentation](https://hexdocs.pm/supabase_potion/Supabase.html#module-starting-a-client):\n\n```elixir\niex> Supabase.init_client(%{name: Conn, conn: %{base_url: \" \", api_key: \" \"}})\n{:ok, #PID<>}\n```\n\nNow you can pass the Client to the `Supabase.GoTrue` functions as a `PID` or the name that was registered on the client initialization:\n\n```elixir\niex> Supabase.GoTrue.sign_in_with_password(pid | client_name, %{} = params)\n```\n\nThis implementation also exposes an `Supaabse.GoTrue.Admin` function to interact with users with super powers:\n```elixir\niex> Supabase.GoTrue.Admin.create_user(pid | client_name, %{} = params)\n```","title":"Usage - Supabase GoTrue","ref":"readme.html#usage"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}